CREATE OR REPLACE FUNCTION imet_assessment_v2.get_imet_evaluation_stats_cm_pr10(
    item_class text,
    tablename text,
    field_value text,
    field_group_element text)
    RETURNS TABLE(formid integer, section text, value_p double precision)
    LANGUAGE 'plpgsql'

    COST 100
    VOLATILE
    ROWS 1000
AS $BODY$

declare
    schemaname text;
    --field_value text;
    sql text;

BEGIN
    schemaname:= 'imet';

    sql := '
  with table0 as (
 select "FormID" as formid,
	case
	  when "Cooperation"=-99 then 0
	else "Cooperation"
	end as score,
	coalesce("MPInvolvement",0) + coalesce("BAInvolvement",0)+ coalesce("EEInvolvement",0) + coalesce("MPIImplementation",0)
	  as weights,
	group_key

	from imet.eval_stakeholder_cooperation

), table1 as (
   select
   formid,
   sum( weights) as sw,
   sum( score/3.0 * weights )  as wi,
   group_key
	from table0 group by formid,group_key
), table2 as(
	select
   formid,
   ''PR10''::text as section,
	sum(wi)/ nullif(sum(sw),0)*100::double precision as value_p
	from table1
    group by formid
)
select * from table2
  ';

    RETURN QUERY EXECUTE sql;
END;

$BODY$;